#
# spec file for package php7-pear
#
# Copyright (c) 2020 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global peardir %{_datadir}/php7/PEAR
%global metadir %{_localstatedir}/lib/pear

%define pear_module_version(m) %(sed -n 's/.*=>.*%{1}-\\(.*\\)\\.tar.*/\\1/p' %{SOURCE0})

Name:           php7-pear
Version:        1.10.19
Release:        lp152.2.3.1
Summary:        PHP Extension and Application Repository
License:        BSD-2-Clause
Group:          Development/Libraries/PHP
URL:            https://pear.php.net/package/pearweb_phars
Source0:        https://github.com/pear/pearweb_phars/raw/v%{version}/install-pear-nozlib.phar
Source1:        https://github.com/pear/pearweb_phars/raw/v%{version}/install-pear-nozlib.sig#/install-pear-nozlib.phar.sig
Source2:        %{name}.keyring
Source3:        %{name}.rpmlintrc
# bsc#1187372 -- https://github.com/pear/pear-core/pull/115
Patch0:         php7-pear-undefined-variables.patch
BuildRequires:  php7
Requires:       php7
Recommends:     php7-openssl
Provides:       php-pear = %{version}
Provides:       php-pear(Archive_Tar) = %pear_module_version Archive_Tar
Provides:       php-pear(Console_Getopt) = %pear_module_version Console_Getopt
Provides:       php-pear(PEAR) = %pear_module_version PEAR
Provides:       php-pear(Structures_Graph) = %pear_module_version Structures_Graph
Provides:       php-pear(XML_Util) = %pear_module_version XML_Util
Obsoletes:      php-pear < %{version}
Provides:       php7-pear-Archive_Tar
Obsoletes:      php7-pear-Archive_Tar
BuildArch:      noarch

%description
PEAR is a code repository for PHP extensions and PHP library code
similar to TeX's CTAN and Perl's CPAN. This package provides an access
to the repository.

See https://pear.php.net/manual for more details.

%package -n php7-pecl
Summary:        PHP Extension Community Library
Group:          Development/Libraries/PHP
Requires:       autoconf
Requires:       automake
Requires:       gcc-c++
Requires:       libtool
Requires:       php7-pear = %{version}
Provides:       php-pecl = %{version}
Obsoletes:      php-pecl < %{version}
Conflicts:      php7-devel < 7.4
BuildArch:      noarch

%description -n php7-pecl
PECL is a repository for PHP Extensions, providing a directory of
all known extensions and hosting facilities for downloading and
development of PHP extensions.

See https://pecl.php.net for more details.

%prep
# Empty prep section, nothing to prepare

%build
# Empty build section, nothing to build

%install
export PHP_PEAR_INSTALL_DIR=%{peardir}
export PHP_PEAR_METADATA_DIR=%{metadir}
export PHP_PEAR_SIG_BIN=%{_bindir}/gpg
export PHP_PEAR_SYSCONF_DIR=%{_sysconfdir}/php7/cli
export INSTALL_ROOT=%{buildroot}

install -d %{buildroot}%{_localstatedir}/{cache,lib}/pear

php -d date.timezone=UTC -d memory_limit=64M -d short_open_tag=0 -d safe_mode=0 \
	-d 'error_reporting=E_ALL&~E_DEPRECATED' -d detect_unicode=0 %{SOURCE0} \
	--force \
	--bin      %{_bindir} \
	--cache    %{_localstatedir}/cache/pear \
	--dir      %{peardir} \
	--man      %{_mandir} \
	--metadata %{metadir} \
	--www      %{peardir}/htdocs
patch -p0 -d %{buildroot}/%{peardir} < %{PATCH0}

%pre
if [ -d %{peardir}/.registry -a ! -d %{metadir}/.registry ]; then
    mkdir -p %{metadir}
    cp -af %{peardir}/{.channels,.registry} %{metadir}
fi

%posttrans
mdir=$(%{_bindir}/pear config-get metadata_dir system)
if [ "${mdir}" != "%{metadir}" -a -d %{metadir}/.registry ]; then
    %{_bindir}/pear config-set metadata_dir %{metadir} system
    rm -rf %{peardir}/{.channels,.registry}
fi

%files
%{_bindir}/pear
%config(noreplace) %{_sysconfdir}/php7/cli/pear.conf
%dir %{_localstatedir}/cache/pear
%dir %{_localstatedir}/lib/pear
%dir %{peardir}
%docdir %{peardir}/doc
%{peardir}/*
%{metadir}/.??*
%exclude %{_bindir}/peardev
%exclude %{peardir}/doc/PEAR/INSTALL
%exclude %{peardir}/test

%files -n php7-pecl
%{_bindir}/pecl

%changelog
* Wed Jun 16 2021 pgajdos@suse.com
- added patches
  fix bsc#1187372 -- https://github.com/pear/pear-core/pull/115
  + php7-pear-undefined-variables.patch
* Tue May 19 2020 pgajdos@suse.com
- provides php-pear-Archive_Tar and obsoletes php-pear-Archive_Tar
* Sun Apr 19 2020 Arjen de Korte <suse+build@de-korte.org>
- Update to version 1.10.19
  - PEAR 1.10.12
  * adjust dependencies based on new releases
  - XML_Util 1.4.5
  * fix Trying to access array offset on value of type int
* Fri Apr 10 2020 Arjen de Korte <suse+build@de-korte.org>
- Update to version 1.10.18
- Remove pear-cacheid-array-check.patch (upstreamed)
- Contents of .filemap are now sorted internally
* Fri Feb 28 2020 Arjen de Korte <suse+build@de-korte.org>
- Sort contents of .filemap to make build reproducible
* Sat Dec  7 2019 Arjen de Korte <suse+build@de-korte.org>
- Apply upstream patch for https://bugs.php.net/78890
  + pear-cacheid-array-check.patch
- Recommend php7-openssl to allow https sources to be used
- Modify metadata_dir for system configuration only
- Add /var/lib/pear directory where xml files are stored
- Cleanup %%files section
* Tue Nov 26 2019 Arjen de Korte <suse+build@de-korte.org>
- Only use the GPG keys of Chuck Burgess. Extracted from the
  Release Manager public keys.
- Add release versions of PEAR modules
* Tue Nov 26 2019 Arjen de Korte <suse+build@de-korte.org>
- Install metadata files (registry, filemap, channels, ...) in
  /var/lib/pear/ instead of /usr/share/php7/PEAR/
* Mon Nov 25 2019 Arjen de Korte <suse+build@de-korte.org>
- Create php7-pecl subpackage for PECL builds
* Sat Nov 23 2019 Arjen de Korte <suse+build@de-korte.org>
- Update to version 1.10.17
- Package separately, as builtin PEAR was deprecated in PHP-7.4
